@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 1998 - 2018
+  Copyright (c) 1998 - 2020
   CLST  - Radboud University
   ILK   - Tilburg University
   CLiPS - University of Antwerp
@@ -30,9 +30,10 @@
 
 #include "mbt/MbtAPI.h"
 #include "ticcutils/ServerBase.h"
+#include "ticcutils/json.hpp"
 
 namespace MbtServer {
-  using namespace TimblServer;
+  using namespace TiCCServer;
 
   class MbtServerClass : public TcpServerBase {
     friend class Tagger::TaggerClass;
@@ -46,6 +47,18 @@ namespace MbtServer {
     std::map<std::string, Tagger::TaggerClass *> experiments;
   };
 
+  class MbtJSONServerClass : public MbtServerClass {
+    friend class Tagger::TaggerClass;
+  public:
+    explicit MbtJSONServerClass( const TiCC::Configuration *c ):
+    MbtServerClass(c)
+    {};
+  private:
+    void callback( childArgs* );
+  };
+
   void StartServer( TiCC::CL_Options& );
+  void StartJSONServer( TiCC::CL_Options& );
+
 }
 #endif
