@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 1998 - 2018
+  Copyright (c) 1998 - 2020
   CLST  - Radboud University
   ILK   - Tilburg University
   CLiPS - University of Antwerp
@@ -30,10 +30,18 @@
 #include <iostream>
 #include "mbtserver/MbtServerBase.h"
 
+using namespace std;
+
 int main( int argc, const char *argv[]) {
-  TiCC::CL_Options opts( Tagger::mbt_short_opts + "S:",
-			 Tagger::mbt_long_opts + ",debug,config:,logfile:,pidfile:,daemonize:" );
-  opts.init( argc, argv );
+  TiCC::CL_Options opts( Tagger::mbt_short_opts + TiCCServer::serv_short_opts,
+			 Tagger::mbt_long_opts + TiCCServer::serv_long_opts );
+  try {
+    opts.init( argc, argv );
+  }
+  catch ( const exception& e ){
+    cerr << e.what() << endl;
+    exit(EXIT_FAILURE);
+  }
   MbtServer::StartServer( opts );
   exit(EXIT_SUCCESS);
 }
