@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 1998 - 2018
+  Copyright (c) 1998 - 2020
   CLST  - Radboud University
   ILK   - Tilburg University
   CLiPS - University of Antwerp
@@ -43,8 +43,8 @@ using namespace Timbl;
 using namespace Tagger;
 using namespace TiCC;
 
-#define SLOG (*Log(theServer->myLog))
-#define SDBG (*Dbg(theServer->myLog))
+#define SLOG (*Log(theServer->logstream()))
+#define SDBG (*Dbg(theServer->logstream()))
 
 namespace MbtServer {
 
@@ -80,13 +80,13 @@ namespace MbtServer {
       opts.init( it.second );
       exp->parse_run_args( opts, true );
       exp->set_default_filenames();
-      exp->setLog( myLog );
+      exp->setLog( logstream() );
       if ( exp->InitTagging() ){
-	cerr << "Created server " << key << endl;
+	cerr << "Created a tagger " << key << endl;
 	experiments[key] = exp;
       }
       else {
-	cerr << "failed to created a server with name=" << key << endl;
+	cerr << "failed to created a tagger with name=" << key << endl;
 	cerr << "and options = " << it.second << endl;
 	delete exp;
       }
@@ -106,28 +106,28 @@ namespace MbtServer {
   }
 
   MbtServerClass::MbtServerClass( const TiCC::Configuration *c ):
-    TcpServerBase( c ) {
-    myLog.message("MbtServer:");
-    myLog.setstamp(StampMessage);
-    if ( doDebug() )
-      myLog.setlevel( LogHeavy );
+    TcpServerBase( c, &experiments ) {
+    logstream().message("MbtServer:");
+    logstream().setstamp(StampMessage);
+    if ( doDebug() ){
+      logstream().setlevel( LogHeavy );
+    }
     cerr << "mbtserver " << VERSION << endl;
     cerr << "based on " << Timbl::VersionName() << " and "
-	 << TimblServer::VersionName() << endl;
+	 << TiCCServer::VersionName() << endl;
+
     createServers( c );
     if ( experiments.empty() ){
       cerr << "starting the server failed." << endl;
       usage();
       exit( EXIT_FAILURE );
     }
-    callback_data = &experiments;
   }
 
   MbtServerClass::~MbtServerClass(){
     for ( const auto& it : experiments ){
       delete it.second;
     }
-    delete config;
   }
 
   inline void Split( const string& line, string& com, string& rest ){
@@ -145,15 +145,15 @@ namespace MbtServer {
   // ***** This is the routine that is executed from a new thread **********
   void MbtServerClass::callback( childArgs *args ){
     ServerBase *theServer = args->mother();
-    map<string, TaggerClass*> *experiments =
-      static_cast<map<string, TaggerClass*> *>(callback_data);
+    map<string, TaggerClass*> experiments =
+      *(static_cast<const map<string, TaggerClass*> *>(callback_data()));
 
     args->os() << "Welcome to the Mbt server." << endl;
     string baseName = "default";
-    if ( experiments->size() > 1 ){
-      map<string,TaggerClass*>::const_iterator it = experiments->begin();
+    if ( experiments.size() > 1 ){
+      map<string,TaggerClass*>::const_iterator it = experiments.begin();
       bool first = true;
-      while ( it != experiments->end() ){
+      while ( it != experiments.end() ){
 	if ( it->first != "default" ){
 	  if ( first ){
 	    args->os() << "available bases: ";
@@ -179,8 +179,8 @@ namespace MbtServer {
       if ( command == "base" ){
 	baseName = param;
       }
-      if ( experiments->find( baseName ) != experiments->end() ){
-	exp = (*experiments)[baseName]->clone( );
+      if ( experiments.find( baseName ) != experiments.end() ){
+	exp = experiments[baseName]->clone( );
 	if ( baseName != "default" ){
 	  args->os() << "base set to '" << baseName << "'" << endl;
 	  SLOG << "Set basename " << baseName << endl;
@@ -191,29 +191,56 @@ namespace MbtServer {
 	SLOG << "Invalid basename " << baseName << " rejected" << endl;
       }
       if ( exp ){
-	string result;
-	if ( command != "base" ){
-	  SDBG << "input line '" << Line << "'" << endl;
-	  int num = exp->TagLine( Line, result );
+	if ( exp->enriched() ){
+	  string text_block;
+	  if ( command != "base" ){
+	    SDBG << "input line '" << Line << "'" << endl;
+	    text_block += Line + "\n";
+	  }
+	  while ( getline( args->is(), Line ) ){
+	    string::size_type pos = Line.find('\r');
+	    if ( pos != string::npos )
+	      Line.erase(pos,1);
+	    SDBG << "input line '" << Line << "'" << endl;
+	    if ( Line == "<utt>" ){
+	      break;
+	    }
+	    text_block += Line + "\n";
+	  }
+	  string result;
+	  SDBG << "call TagLine '" << text_block << "'" << endl;
+	  int num = exp->TagLine( text_block, result );
 	  SDBG << "result     '" << result << "'" << endl;
 	  if ( num > 0 ){
 	    nw += num;
 	    args->os() << result << endl;
 	  }
 	}
-	while ( getline( args->is(), Line ) ){
-	  string::size_type pos = Line.find('\r');
-	  if ( pos != string::npos )
-	    Line.erase(pos,1);
-	  SDBG << "input line '" << Line << "'" << endl;
-	  int num = exp->TagLine( Line, result );
-	  SDBG << "result     '" << result << "'" << endl;
-	  if ( num > 0 ){
-	    nw += num;
-	    args->os() << result << endl;
+	else {
+	  string result;
+	  if ( command != "base" ){
+	    SDBG << "input line '" << Line << "'" << endl;
+	    int num = exp->TagLine( Line, result );
+	    SDBG << "result     '" << result << "'" << endl;
+	    if ( num > 0 ){
+	      nw += num;
+	      args->os() << result << endl;
+	    }
+	  }
+	  while ( getline( args->is(), Line ) ){
+	    string::size_type pos = Line.find('\r');
+	    if ( pos != string::npos )
+	      Line.erase(pos,1);
+	    SDBG << "input line '" << Line << "'" << endl;
+	    int num = exp->TagLine( Line, result );
+	    SDBG << "result     '" << result << "'" << endl;
+	    if ( num > 0 ){
+	      nw += num;
+	      args->os() << result << endl;
+	    }
+	    else
+	      break;
 	  }
-	  else
-	    break;
 	}
       }
     }
@@ -224,7 +251,7 @@ namespace MbtServer {
   void StartServer( TiCC::CL_Options& opts ){
     if ( opts.is_present( "h" ) ||
 	 opts.is_present( "help" ) ){
-      usage();
+      ServerBase::server_usage();
       exit( EXIT_SUCCESS );
     }
     if ( opts.is_present( "V" ) ||
@@ -232,8 +259,20 @@ namespace MbtServer {
       exit( EXIT_SUCCESS );
     }
     Configuration *config = initServerConfig( opts );
-    MbtServerClass server( config );
-    server.Run();
+    if ( config ){
+      if ( config->lookUp("protocol") == "json" ){
+	LOG << "STARTING A JSON SERVER!" << endl;
+	MbtJSONServerClass server( config );
+	server.Run();
+      }
+      else {
+	MbtServerClass server( config );
+	server.Run();
+      }
+    }
+    else {
+      cerr << "starting failed" << endl;
+      exit( EXIT_FAILURE );
+    }
   }
-
 }
